Finding class

Contains information about a finding.

Constructors

Finding({required DateTime analyzedAt, required Map<String, String> condition, required DateTime createdAt, required String id, required String resourceOwnerAccount, required ResourceType resourceType, required FindingStatus status, required DateTime updatedAt, List<String>? action, String? error, bool? isPublic, Map<String, String>? principal, String? resource, List<FindingSource>? sources})
Finding.fromJson(Map<String, dynamic> json)
factory

Properties

action → List<String>?
The action in the analyzed policy statement that an external principal has permission to use.
final
analyzedAt → DateTime
The time at which the resource was analyzed.
final
condition → Map<String, String>
The condition in the analyzed policy statement that resulted in a finding.
final
createdAt → DateTime
The time at which the finding was generated.
final
error → String?
An error.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The ID of the finding.
final
isPublic → bool?
Indicates whether the policy that generated the finding allows public access to the resource.
final
principal → Map<String, String>?
The external principal that access to a resource within the zone of trust.
final
resource → String?
The resource that an external principal has access to.
final
resourceOwnerAccount → String
The AWS account ID that owns the resource.
final
resourceType → ResourceType
The type of the resource reported in the finding.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources → List<FindingSource>?
The sources of the finding. This indicates how the access that generated the finding is granted. It is populated for Amazon S3 bucket findings.
final
status → FindingStatus
The current status of the finding.
final
updatedAt → DateTime
The time at which the finding was updated.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited