FindingSource class

The source of the finding. This indicates how the access that generated the finding is granted. It is populated for Amazon S3 bucket findings.

Constructors

FindingSource({required FindingSourceType type, FindingSourceDetail? detail})
FindingSource.fromJson(Map<String, dynamic> json)
factory

Properties

detail → FindingSourceDetail?
Includes details about how the access that generated the finding is granted. This is populated for Amazon S3 bucket findings.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → FindingSourceType
Indicates the type of access that generated the finding.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited