GetArchiveRuleResponse class

The response to the request.

Constructors

GetArchiveRuleResponse({required ArchiveRuleSummary archiveRule})
GetArchiveRuleResponse.fromJson(Map<String, dynamic> json)
factory

Properties

archiveRule → ArchiveRuleSummary
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited